@@ -22,7 +22,7 @@ class BrowserV2:
         exit(1)
 
     @classmethod
-    def delay(cls, start, end) -> None:
+    def delay(cls, start=3, end=6) -> None:
         Utils.time_to_sleep(start=start, end=end)
 
     def __init__(
@@ -31,13 +31,15 @@ class BrowserV2:
             profile_path: str = None,
             rotative_agent: bool = False,
             version_main: str = None,
-            use_profile: bool = False
+            use_profile: bool = False,
+            use_headless: bool = False
     ) -> None:
 
         self.__version_main = version_main
         self.__active_sleep = active_sleep
         self.__rotative_agent = rotative_agent
         self.__use_profile = use_profile
+        self.__use_headless = use_headless
         BrowserV2.__options = uc.ChromeOptions()
 
         if (profile_path is not None) and (use_profile is False):
@@ -51,9 +53,11 @@ class BrowserV2:
                 BrowserV2.__options.add_argument('--user-data-dir=' + profile_path)
 
         BrowserV2.user_agents = list(Utils.get_agent_users())
-
+        if self.__use_headless:
+            BrowserV2.__options.add_argument('--headless')
         # just some options passing in to skip annoying popups
         BrowserV2.__options.add_argument('--no-first-run --no-service-autorun --password-store=basic')
+        BrowserV2.__options.add_argument('--start-maximized')
         self.driver = uc.Chrome(options=BrowserV2.__options, version_main=self.__version_main)
 
     def navigate(self, url: str) -> None:
@@ -69,20 +73,33 @@ class BrowserV2:
     def click(self, xpath: str):
         return self.driver.find_element(By.XPATH, xpath).click()
 
+    def clear(self, xpath):
+        self.driver.find_element(By.XPATH, xpath).clear()
+
     def wait_to_click(self, xpath, time=10):
         return WebDriverWait(self.driver, time).until(EC.element_to_be_clickable((By.XPATH, xpath))).click()
 
     def wait_frame_switch_to(self, xpath, time=10):
         WebDriverWait(self.driver, time).until(EC.frame_to_be_available_and_switch_to_it((By.XPATH, xpath)))
 
+    def wait_element(self, xpath, time=10):
+        try:
+            WebDriverWait(self.driver, time).until(EC.presence_of_element_located((By.XPATH, xpath)))
+            return
+        except:
+            return False
+
+    def query_selector(self, query):
+        return self.driver.execute_script(f'return {query}')
+
     def switch_to_frame_default(self):
         self.driver.switch_to.default_content()
 
     def switch_to_frame(self, frame):
         self.driver.switch_to.frame(frame)
 
-    def screenshot(self, xpath, filename):
-        return self.driver.find_element(By.XPATH, xpath).screenshot(filename)
+    def screenshot(self, filename):
+        return self.driver.save_screenshot(filename)
 
     def get_href(self, xpath):
         return self.driver.find_element(By.XPATH, xpath).get_attribute('href')
